/*
 * Copyright (c) 2010 David McIntosh <dmcintosh@df12.net>
 *
 * Permission to use, copy, modify, and distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */

#import <AppKit/AppKit.h>
#import "util.h"
#import "constants.h"
#import "NSDate+GanttAdditions.h"

typedef enum
{
    GC_DRAG_NONE,
    GC_DRAG_START,
    GC_DRAG_END,
    GC_DRAG_COMPLETION
} GanttCellDragState;

@interface GanttCell : NSActionCell
{
    NSDate *_startDate;
    NSDate *_endDate;
    NSDate *_originDate;
    NSTimeInterval extentIntv;
    NSTimeInterval _gridInterval;
    float _completion;

    float _pixelsPerSec;
    NSRect barRect;
    NSRect progressRect;

    BOOL _viewIsValid;
    NSRect bounds;

    GanttCellDragState dragState;
    float yOffset;

    NSInteger _index;
}

- (void)setIndex:(NSInteger)val;
- (NSInteger)index;
- (void)setOriginDate:(NSDate *)aDate;
- (void)setStartDate:(NSDate *)aDate;
- (NSDate *)startDate;
- (void)setEndDate:(NSDate *)aDate;
- (NSDate *)endDate;
- (void)setGridInterval:(NSTimeInterval)anInterval;
- (NSTimeInterval)gridInterval;
- (void)setCompletion:(float)val;
- (float)completion;

- (NSRect)barRect;
- (NSRect)progressRectForZoom:(float)zoom;

- (void)setBounds:(NSRect)aRect;
- (void)invalidateView;

- (NSRect)resizeLeftRectInView:(NSView *)aView;
- (NSRect)resizeRightRectInView:(NSView *)aView;
- (NSRect)interiorRect;

- (void)resetCursorRectsForFrame:(NSRect)frame
                   inView:(NSView *)view;


@end
